.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _canary.plugins.builtin.html:

html
====

.. automodule:: _canary.plugins.builtin.html
   :members:
   :undoc-members:
   :show-inheritance:
